pycep\_correios package
=======================

Submodules
----------

pycep\_correios.client module
-----------------------------

.. automodule:: pycep_correios.client
   :members:
   :undoc-members:
   :show-inheritance:

pycep\_correios.excecoes module
-------------------------------

.. automodule:: pycep_correios.excecoes
   :members:
   :undoc-members:
   :show-inheritance:

pycep\_correios.exceptions module
---------------------------------

.. automodule:: pycep_correios.exceptions
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pycep_correios
   :members:
   :undoc-members:
   :show-inheritance:
